OC.L10N.register(
    "spreed",
    {
    "Enter name for a new conversation" : "Ange namn för en ny konversation",
    "{name} (public)" : "{name} (publik)",
    "New conversation …" : "Ny konversation",
    "Participants" : "Deltagare",
    "Projects" : "Projekt",
    "Chat" : "Chat",
    "Talk" : "Talk",
    "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "Samtal med fler än 4 deltagare utan att en extern signalserver kan uppleva anslutningsproblem och orsaka hög belastning på deltagande enheter.",
    "Exit fullscreen (f)" : "Avsluta fullskärmsläge (f)",
    "Fullscreen (f)" : "Fullskärm (f)",
    "Copy" : "Kopiera",
    "Copied!" : "Kopierat!",
    "Not supported!" : "Ej kompatibel!",
    "Press ⌘-C to copy." : "Tryck ⌘-C för att kopiera.",
    "Press Ctrl-C to copy." : "Tryck Ctrl-C för att kopiera.",
    "Error while getting the room ID" : "Fel vid mottagande av rum-ID",
    "Start a conversation" : "Starta en konversation",
    "Share this file with others to discuss" : "Dela den här filen med andra för att diskutera",
    "Share" : "Dela",
    "Room name can not be empty" : "Rumsnamn kan inte vara tomt",
    "Request password" : "Begär lösenord",
    "Error requesting the password." : "Fel vid begäran av lösenord.",
    "Please enter the password for this call" : "Var god ange lösenordet för detta samtal",
    "Password required" : "Lösenord krävs",
    "Password" : "Lösenord",
    "Cancel" : "Avbryt",
    "Submit" : "Skicka",
    "Leave call" : "Lämna samtalet",
    "Join call" : "Gå med i samtal",
    "Start call" : "Starta samtal",
    "Calls are disabled in this conversation." : "Samtal är inaktiverade i den här konversationen.",
    "Go to file" : "Gå till fil",
    "Share link" : "Dela länk",
    "Copy link" : "Kopiera länk",
    "Enable for" : "Aktivera för",
    "All participants" : "Alla deltagare",
    "Moderators only" : "Endast moderatorer",
    "Start time (optional)" : "Starttid (valfritt)",
    "Change password" : "Byt lösenord",
    "Set password" : "Sätt lösenord",
    "Error occurred while renaming the room" : "Fel uppstod vid namnändring av rum",
    "Name" : "Namn",
    "Conversation name" : "Konversationens namn",
    "Rename" : "Byt namn",
    "Link copied!" : "Länk kopierad!",
    "Conversation with {name}" : "Konversation med {name}",
    "Error occurred while making the room public" : "Fel uppstod när rummet skulle göras offentligt",
    "Error occurred while making the room private" : "Fel uppstod när rummet skulle göras privat",
    "Error occurred while setting password" : "Fel inträffade när lösenord sattes",
    "Error occurred while enabling for all participants" : "Fel uppstod vid aktivering för alla deltagare",
    "Error occurred while enabling only for moderators" : "Fel uppstod vid aktivering för endast moderatorer",
    "Invalid start time format" : "Ogiltigt format för starttid",
    "Error occurred while setting the lobby start time" : "Fel uppstod vid inställning av starttid för lobby",
    "You" : "Du",
    "Guest" : "Gäst",
    "No messages yet, start the conversation!" : "Inga meddelanden än, starta konversationen!",
    "New message …" : "Nytt meddelande",
    "Send" : "Skicka",
    "You can not send messages, because the conversation is locked." : "Du kan inte skicka meddelanden, eftersom konversationen är låst.",
    "The conversation is locked." : "Konversationen är låst.",
    "[Unknown user name]" : "[Okänt användarnam]",
    "Today" : "Idag",
    "Yesterday" : "Igår",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The message you are trying to send is too long" : "Meddelandet du försöker skicka är för långt",
    "Error occurred while sending message" : "Fel inträffade när meddelande sändes",
    "File to share" : "Fil att dela",
    "Error while sharing" : "Fel vid delning",
    "Edit" : "Ändra",
    "Join a conversation or start a new one" : "Anslut till en konversation eller starta en ny",
    "Say hi to your friends and colleagues!" : "Säg hej till dina vänner och kollegor!",
    "You are currently waiting in the lobby" : "Du väntar för närvarande i lobbyn",
    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Du väntar för närvarande i lobbyn. Detta möte är planerat till {startTime}",
    "No other people in this call" : "Inga andra personer i detta samtal",
    "Waiting for {participantName} to join the call …" : "Väntar på att {participantName} ansluter sig till samtalet ...",
    "Waiting for others to join the call …" : "Väntar på andra ansluter sig till samtalet ...",
    "You can invite others in the participant tab of the sidebar" : "Du kan bjuda in andra på fliken deltagare i sidofältet",
    "Share this link to invite others!" : "Dela denna länk för att bjuda in andra!",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan bjuda in andra på fliken deltagare i sidofältet eller dela den här länken!",
    "WebRTC is not supported in your browser :-/" : "WebRTC är inte kompatibelt med din webbläsare :-/",
    "Please use a different browser like Firefox or Chrome" : "Vänligen använd en annan webbläsare som t.ex Firefox eller Chrome",
    "Waiting for camera and microphone permissions" : "Väntar på godkännande att använda kamera och mikrofon",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Vänligen ge din webbläsare tillåtelse att använda din kamera och mikrofon för att kunna använda denna funktion.",
    "This conversation has ended" : "Denna konversation har avslutats",
    "Set your name in the chat window so other participants can identify you better." : "Ange ditt namn i chattfönstret så andra deltagare kan identifiera dig bättre. ",
    "Mute audio" : "Stäng av ljudet",
    "Disable video" : "Stäng av video",
    "Share screen" : "Dela skärm",
    "Share whole screen" : "Dela hela skärmen",
    "Share a single window" : "Dela ett fönster",
    "Show your screen" : "Visa din skärm",
    "Stop screensharing" : "Stoppa skärmdelning",
    "Mute audio (m)" : "Ljud av (m)",
    "Unmute audio (m)" : "Ljud på (m)",
    "No audio" : "Inget ljud",
    "Disable video (v)" : "Inaktivera video (v)",
    "Enable video (v)" : "Aktivera video (v)",
    "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Aktivera video (v) - Din anslutning får ett kort avbrott när du aktiverar videon för första gången",
    "No Camera" : "Ingen kamera",
    "Screensharing is not supported by your browser." : "Skärmdelning fungerar inte i din nuvarande webbläsare.",
    "Screensharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver HTTPS",
    "Screensharing options" : "Skärmdelningsalternativ",
    "Sharing your screen only works with Firefox version 52 or newer." : "Skärmdelning fungerar endast med Firefox version 52 eller nyare.",
    "Screensharing extension is required to share your screen." : "Skärmdelningstillägg krävs för att dela din skärm.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Vänligen använd en annan webbläsare som t.ex Firefox eller Chrome för att dela din skärm.",
    "An error occurred while starting screensharing." : "Ett fel uppstod vid skärmdelning.",
    "Enable screensharing" : "Tillåt skärmdelning",
    "moderator" : "moderator",
    "Demote from moderator" : "Degradera från moderator",
    "Promote to moderator" : "Befordra till moderator",
    "Remove participant" : "Ta bort deltagare",
    "Error while promoting user to moderator" : "Kunde inte göra användaren till moderator",
    "Error while demoting moderator" : "Kunde inte ta bort moderator",
    "Error while removing user from room" : "Kunde inte ta bort användaren från rummet",
    "Add participant …" : "Lägg till deltagare",
    "Favorited" : "Favorit",
    "Remove from favorites" : "Ta bort från favoriter",
    "Add to favorites" : "Lägg till som favorit",
    "Chat notifications" : "Chatt-notifieringar",
    "All messages" : "Alla meddelanden",
    "@-mentions only" : "@-mentions only",
    "Off" : "Av",
    "Leave conversation" : "Lämna konversationen",
    "Delete conversation" : "Radera konversationen",
    "You need to promote a new moderator before you can leave the conversation." : "Du måste tilldela en ny moderator innan du kan lämna konversationen.",
    "Your screen" : "Din skärm",
    "{participantName}'s screen" : "{participantName}'s skärm",
    "Guest's screen" : "Gästskärm",
    "Close" : "Stäng",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Du verkar prata med avstängd mikrofon, sätt på mikrofonen för att andra ska höra dig",
    "Show screen" : "Visa skärm",
    "Enable video" : "Aktivera video",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Det tar längre tid än väntat. Har mediarättigheter redan beviljats (eller avvisats)? Om ja, starta om din webbläsare, eftersom ljud och video misslyckas",
    "Access to microphone & camera is only possible with HTTPS" : "Tillgång till mikrofon och kamera är endast möjligt via HTTPS",
    "Please move your setup to HTTPS" : "Vänligen flytta din inställning till HTTPS",
    "Access to microphone & camera was denied" : "Tillgång till mikrofon och kamera blev nekad",
    "WebRTC is not supported in your browser" : "WebRTC är inte kompatibelt med din webbläsare",
    "Error while accessing microphone & camera" : "Kunde ej ansluta mikrofon och kamera",
    "a conversation" : "en konversation",
    "(Duration %s)" : "(Varaktighet%s)",
    "You attended a call with {user1}" : "Du deltog i ett samtal med {user1}",
    "_%n guest_::_%n guests_" : ["%n gäst","%n gäster"],
    "You attended a call with {user1} and {user2}" : "Du deltog i ett samtal med {user1} och {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Du deltog i ett samtal med {user1}, {user2} och {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Du deltog i ett samtal med {user1}, {user2}, {user3} och {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Du deltog i ett samtal med {user1}, {user2}, {user3}, {user4} och {user5}",
    "_%n other_::_%n others_" : ["%n annan","%n andra"],
    "{actor} invited you to {call}" : "{actor} bjöd in dig till {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Du blev inbjuden till en <strong>konversation</strong> eller hade ett <strong>samtal</strong>",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Välkommen till Nextcloud Talk!\nI denna konversation kommer du att bli informerad om nya funktioner som finns i Nextcloud Talk.",
    "New in Talk 6" : "Nytt i Talk 6",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge och Safari kan nu användas för att delta i ljud- och videosamtal",
    "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- En-till-en-konversationer är nu beständiga och kan inte längre omvandlas till gruppsamtal av misstag. När en av deltagarna lämnar samtalet raderas konversationen inte längre automatiskt. Endast om båda deltagarna lämnar samtalet raderas konversationen från servern.",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Du kan nu meddela alla deltagare genom att skicka \"@all\" till chatten",
    "- With the \"arrow-up\" key you can repost your last message" : "- Med \"pil upp\" -knappen kan du skicka om ditt senaste meddelande",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk kan nu ha kommandon, skicka \"/help\" som ett chattmeddelande för att se om din administratör har konfigurerat några",
    "- With projects you can create quick links between conversations, files and other items" : "- Med projekt kan du skapa snabba länkar mellan konversationer, filer och andra objekt",
    "New in Talk 7" : "Nytt i Talk 7",
    "- You can now mention guests in the chat" : "- Du kan nu nämna gäster i chatten",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- Konversationer kan nu ha en lobby. Detta gör att moderatorer nu kan förbereda mötet, medan användare och gäster måste vänta.",
    "There are currently no commands available." : "Det finns för närvarande inga kommandon tillgängliga.",
    "The command does not exist" : "Kommandot finns inte",
    "An error occurred while running the command. Please ask an administrator to check the logs." : "Ett fel inträffade under körning av kommandot. Be en administratör att kontrollera loggarna.",
    "Talk updates ✅" : "Talk uppdateringar ✅",
    "{actor} created the conversation" : "{actor} skapade konversationen",
    "You created the conversation" : "Du skapade konversationen",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} bytte namn på konversationen från \"%1$s\" till \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Du bytte namn på konversationen från \"%1$s\" till \"%2$s\"",
    "{actor} started a call" : "{actor} startade ett samtal",
    "You started a call" : "Du startade ett samtal",
    "{actor} joined the call" : "{actor} gick med i samtalet",
    "You joined the call" : "Du gick med i samtalet",
    "{actor} left the call" : "{actor} lämnade samtalet",
    "You left the call" : "Du lämnade samtalet",
    "{actor} unlocked the conversation" : "{actor} låste upp konversationen",
    "You unlocked the conversation" : "Du låste upp konversationen",
    "{actor} locked the conversation" : "{actor} låste konversationen",
    "You locked the conversation" : "Du låste konversationen",
    "The conversation is now open to everyone" : "Konversationen är nu öppen för alla",
    "{actor} opened the conversation to everyone" : "{actor} öppnade konversationen för alla",
    "You opened the conversation to everyone" : "Du öppnade konversationen för alla",
    "{actor} restricted the conversation to moderators" : "{actor} begränsade konversationen till moderatorer",
    "You restricted the conversation to moderators" : "Du begränsade konversationen till moderatorer",
    "{actor} allowed guests" : "{actor} tillåter gäster",
    "You allowed guests" : "Du tillåter gäster",
    "{actor} disallowed guests" : "{actor} tillåter inte gäster",
    "You disallowed guests" : "Du tillåter inte gäster",
    "{actor} set a password" : "{actor} satte ett lösenord",
    "You set a password" : "Du satte ett lösenord",
    "{actor} removed the password" : "{actor} tog bort lösenordet",
    "You removed the password" : "Du tog bort lösenordet",
    "{actor} added {user}" : "{actor} la till {user}",
    "You joined the conversation" : "Du gick med i konversationen",
    "{actor} joined the conversation" : "{actor} gick med i konversationen",
    "You added {user}" : "Du la till {user}",
    "{actor} added you" : "{actor} la till dig",
    "You left the conversation" : "Du lämnade konversationen",
    "{actor} left the conversation" : "{actor} lämnade konversationen",
    "{actor} removed {user}" : "{actor} tog bort {user}",
    "You removed {user}" : "Du tog bort {user}",
    "{actor} removed you" : "{actor} tog bort dig",
    "{actor} promoted {user} to moderator" : "{actor} gjorde {user} till moderator",
    "You promoted {user} to moderator" : "Du gjorde {user} till moderator",
    "{actor} promoted you to moderator" : "{actor} gjorde dig moderator",
    "{actor} demoted {user} from moderator" : "{actor} tog bort {user} som moderator",
    "You demoted {user} from moderator" : "Du tog bort {user} som moderator",
    "{actor} demoted you from moderator" : "{actor} tog bort dig som moderator",
    "{actor} shared a file which is no longer available" : "{actor} delade en fil som inte längre är tillgänglig",
    "You shared a file which is no longer available" : "Du delade en fil som inte längre är tillgänglig",
    "%s (guest)" : "%s (gäst)",
    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Samtal med %n gäst (Varaktighet {duration})","Samtal med %n gäster (Varaktighet {duration})"],
    "Call with {user1} and {user2} (Duration {duration})" : "Samtal med {user1} och {user2} (Varade {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Samtal med {user1}, {user2} och {user3} (Varade {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Samtal med {user1}, {user2}, {user3} och {user4} (Varade {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Samtal med {user1}, {user2}, {user3}, {user4} och {user5} (Varade {duration})",
    "Talk to %s" : "Prata med %s",
    "File is not shared, or shared but not with the user" : "Filen delas inte eller delas men inte med användaren",
    "%s invited you to a conversation." : "%s bjöd in dig till en konversation.",
    "You were invited to a conversation." : "Du blev inbjuden till en konversation.",
    "Conversation invitation" : "Inbjudan till konversation",
    "Click the button below to join." : "Klicka på knappen nedan för att gå med.",
    "Join »%s«" : "Anslut »%s«",
    "Password request: %s" : "Lösenordsförfrågan: %s",
    "Private conversation" : "Privat konversation",
    "Deleted user (%s)" : "Raderad användare (%s)",
    "{user} sent you a private message" : "{user} skickade dig ett privat meddelande",
    "{user} sent a message in conversation {call}" : "{user} skickade ett meddelande i konversation {call}",
    "A deleted user sent a message in conversation {call}" : "En raderad användare skickade ett meddelande i konversation {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (gäst) skickade ett meddelande i konversationen {call}",
    "A guest sent a message in conversation {call}" : "En gäst skickade ett meddelande i konversation {call}",
    "{user} replied to your private message" : "{user} svarade på ditt privata meddelande",
    "{user} replied to your message in conversation {call}" : "{user} svarade på ditt meddelande i konversationen {call}",
    "A deleted user replied to your message in conversation {call}" : "En raderad användare svarade på ditt meddelande i konversationen {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (gäst) svarade på ditt meddelande i konversationen {call}",
    "A guest replied to your message in conversation {call}" : "En gäst svarade på ditt meddelande i konversationen {call}",
    "{user} mentioned you in a private conversation" : "{user} nämnde dig i en privat konversation",
    "{user} mentioned you in conversation {call}" : "{user} nämnde dig i konversation {call}",
    "A deleted user mentioned you in conversation {call}" : "En raderad användare nämnde dig i konversation {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (gäst) nämnde dig i konversationen {call}",
    "A guest mentioned you in conversation {call}" : "En gäst nämnde dig i konversation {call}",
    "View chat" : "Visa chatt",
    "{user} invited you to a private conversation" : "{user} bjöd in dig till en privat konversation",
    "{user} invited you to a group conversation: {call}" : "{user} bjöd in dig till en gruppkonversation: {call}",
    "Answer call" : "Svara på samtal",
    "{user} wants to talk with you" : "{user} vill prata med dig",
    "Call back" : "Ring tillbaka",
    "You missed a call from {user}" : "Du missade ett samtal från {user}",
    "A group call has started in {call}" : "Ett gruppsamtal har startats i {call}",
    "You missed a group call in {call}" : "Du missade ett gruppsamtal i {call}",
    "{email} is requesting the password to access {file}" : "{email} begär lösenordet för åtkomst till {file}",
    "{email} tried to requested the password to access {file}" : "{email} försökte begära lösenordet för åtkomst till {file}",
    "Someone is requesting the password to access {file}" : "Någon begär lösenordet för att komma åt {file}",
    "Someone tried to requested the password to access {file}" : "Någon försökte begära lösenordet för att komma åt {file}",
    "Invalid date, date format must be YYYY-MM-DD" : "Felaktigt datum, datumformat måste vara ÅÅÅÅ-MM-DD",
    "Conversation not found" : "Konversationen hittades inte",
    "Path is already shared with this room" : "Sökvägen är redan delad med detta rum",
    "Chat, video & audio-conferencing using WebRTC" : "Chatt, video och ljud - konferenser med WebRTC",
    "None" : "Ingen",
    "User" : "Användare",
    "Everyone" : "Alla",
    "Disabled" : "Inaktiverad",
    "Moderators" : "Moderatorer",
    "Users" : "Användare",
    "TURN server URL" : "TURN-server URL",
    "Validate SSL certificate" : "Validera SSL-certifikat",
    "Delete this server" : "Ta bort denna server",
    "STUN server URL" : "STUN-server URL",
    "TURN server secret" : "TURN-server hemlighet",
    "TURN server protocols" : "TURN-server protokoll",
    "UDP and TCP" : "UDP och TCP",
    "UDP only" : "endast UDP",
    "TCP only" : "endast TCP",
    "Test this server" : "Testa denna server",
    "Limit to groups" : "Begränsa till grupper",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "När minst en grupp väljs kan bara personer i de angivna grupperna ingå i konversationer.",
    "Guests can still join public conversations." : "Gäster kan fortfarande delta i publika konversationer.",
    "Users that can not use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Användare som inte kan använda Talk längre kommer fortfarande att listas som deltagare i sina tidigare samtal och även deras chattmeddelanden kommer att behållas.",
    "Limit app usage to groups." : "Begränsa app-användning till grupper",
    "Save changes" : "Spara ändringar",
    "Saving …" : "Sparar ...",
    "Saved!" : "Sparat!",
    "Commands" : "Kommandon",
    "Beta" : "Beta",
    "Command" : "Kommando",
    "Script" : "Skript",
    "Response to" : "Svar till",
    "Enabled for" : "Aktiverad för",
    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our <a {attributes}>documentation ↗</a>." : "Kommandon är en ny beta-funktion i Nextcloud Talk. Det låter dig köra skript på din Nextcloud-server. Du kan definiera dem med vårt kommandoradsgränssnitt. Ett exempel på ett kalkylatorskript finns i vår <a {attributes}>dokumentation ↗</a>.",
    "General settings" : "Allmänna inställningar",
    "Start calls" : "Starta samtal",
    "Users and moderators" : "Användare och moderatorer",
    "Select a conversation to add to the project" : "Välj en konversation som ska läggas till i projektet",
    "Select conversation" : "Välj konversation",
    "Signaling servers" : "Signalservrar",
    "Saved" : "Sparad",
    "Add a new server" : "Lägg till ny server",
    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "En extern signalserver bör eventuellt användas för större installationer. Lämna tomt för att använda den interna signalservern.",
    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Observera att samtal med fler än 4 deltagare utan extern signalserver kan uppleva anslutningsproblem och orsaka hög belastning på deltagande enheter.",
    "Don't warn about connectivity issues in calls with more than 4 participants" : "Varna inte om anslutningsproblem i samtal med fler än 4 deltagare",
    "Shared secret" : "Delad hemlighet",
    "STUN servers" : "STUN-servrar",
    "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server används för att bestämma den offentliga IP-adressen av deltagare bakom en router.",
    "TURN servers" : "TURN-servrar",
    "A TURN server is used to proxy the traffic from participants behind a firewall." : "En TURN-servern används för att tunnla trafiken för användare som sitter bakom en brandvägg.",
    "This conversation is password-protected" : "Denna konversation är lösenordsskyddad",
    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
    "Specify commands the users can use in chats" : "Ange kommandon som användare kan använda i chattar",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En extern signalserver kan eventuellt användas för större installationer. Lämna tomt för att använda den interna signalservern.",
    "TURN server" : "TURN-server",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-servern används för att tunnla trafiken för användare som sitter bakom en brandvägg.",
    "%s Talk on your mobile devices" : "%s Talk på dina mobila enheter",
    "Join conversations at any time, any where, on any device." : "Anslut dig till konversationer när som helst, var som helst och på valfri enhet.",
    "Android app" : "Android-app",
    "iOS app" : " iOS-app",
    "Link to a conversation" : "Länka till en konversation",
    "Signaling server URL" : "Signalserver URL",
    "Delete server" : "Ta bort server",
    "Add new server" : "Lägg till ny server",
    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "Du raderade alla STUN-servrar. Eftersom det nästan alltid behövs har en standard STUN-server lagts till.",
    "TURN server shared secret" : "TURN server delade hemlighet",
    "Test server" : "Testa server",
    "New public conversation" : "Ny publik konversation",
    "New group conversation" : "Ny gruppkonversation",
    "Always notify" : "Meddela alltid",
    "Notify on @-mention" : "Meddela på @-mention",
    "Never notify" : "Meddela aldrig",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Du bjöds in för ett <strong>pratrum</strong> eller hade ett <strong>samtal</strong>",
    "_%n other guest_::_%n other guests_" : ["%n annan gäst","%n andra gäster"],
    ", " : ",",
    "Join now" : "Anslut nu",
    "{user} sent a message in a conversation" : "{user} skickade ett meddelande i en konversation",
    "A deleted user sent a message in a conversation" : "En raderad användare skickade ett meddelande i en konversation",
    "A guest sent a message in a conversation" : "En gäst skickade ett meddelande i en konversation",
    "{user} mentioned you in a conversation" : "{user} nämnde dig i en konversation",
    "A deleted user mentioned you in a conversation" : "En raderad användare nämnde dig i en konversation",
    "A guest mentioned you in a conversation" : "En gäst nämnde dig i en konversation",
    "%s invited you to a private conversation" : "%s bjöd in dig till en privat konversation",
    "%s invited you to a group conversation: %s" : "%s bjöd in dig till en gruppkonversation: %s",
    "%s invited you to a group conversation" : "%s bjöd in dig till en gruppkonversation",
    "{user} invited you to a group conversation" : "{user} bjöd in dig till en gruppkonversation",
    "A group call has started" : "Ett gruppsamtal har startats",
    "{email} requested the password to access {file}" : "{email} begärde lösenordet för åtkomst till {file}",
    "Someone requested the password to access {file}" : "Någon begärde lösenordet för att komma åt {file}",
    "Unnamed conversation" : "Namnlös konversation",
    "Video & audio-conferencing using WebRTC" : "Video- och ljudkonferens med WebRTC",
    "This call is password-protected" : "Detta samtal är lösenordsskyddat",
    "Signaling server" : "Signalserver",
    "* Microsoft Edge and Safari can now be used to participate in audio and video calls" : "* Microsoft Edge och Safari kan nu användas för att delta i ljud- och videosamtal",
    "* One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "* En-till-en-konversationer är nu beständiga och kan inte längre omvandlas till gruppsamtal av misstag. När en av deltagarna lämnar samtalet raderas konversationen inte längre automatiskt. Endast om båda deltagarna lämnar samtalet raderas konversationen från servern.",
    "* You can now notify all participants by posting \"@all\" into the chat" : "* Du kan nu meddela alla deltagare genom att skicka \"@all\" till chatten",
    "* With the \"arrow-up\" key you can repost your last message" : "* Med \"pil upp\" -knappen kan du skicka om ditt senaste meddelande",
    "* Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "* Talk kan nu ha kommandon, skicka \"/help\" som ett chattmeddelande för att se om din administratör har konfigurerat några",
    "* With projects you can create quick links between conversations, files and other items" : "* Med projekt kan du skapa snabba länkar mellan konversationer, filer och andra objekt"
},
"nplurals=2; plural=(n != 1);");
